{% extends "grid/section_1.html" %}


{% block top_ab_a_class %}col-12 col-md-8{% endblock %}
{% block top_ab_b_class %}col-12 col-md-4{% endblock %}

{% block right_single_class %}col-12 col-md-2 offset-md-1{% endblock %}
{% block right_double_class %}col-12 col-md-3 offset-md-1{% endblock %}
