{% load i18n %}
{% load static %}


<h4>{% trans "Attachments" %}</h4>

<!-- ATTACHMENTS -->
<ul class="upload-file-list list-unstyled">
    {% for item in publication.get_attachments %}
    <li>
        <a href="{{ item.file.url }}" target="_blank" rel="noopener" rel="noreferrer">
            <svg class="icon icon-secondary"
                 aria-hidden="true">
                <use xlink:href="{% static '/svg/sprites.svg' %}#it-file"></use>
            </svg>
            <span class="visually-hidden">{% trans "Attachment" %}:</span> {{ item.name }}
        </a>
        <span class="text-muted small">
            &nbsp; {{ item.file_type }} ({{ item.file_size_kb }} KB)
        </span>
    </li>
    {% endfor %}
</ul>
<!-- END ATTACHMENTS -->
