{% load i18n %}
{% load static %}

{% load unicms_templates %}


{% random_id as id %}

<div id="collapseDiv-{{ id }}-lft" class="accordion accordion-left-icon">

    <div class="accordion-item">
        <div class="accordion-header" id="heading-{{ id }}-lft">
            <button class="accordion-button"
                    type="button"
                    data-bs-toggle="collapse"
                    data-bs-target="#collapse-{{ id }}-lft"
                    aria-expanded="false"
                    aria-controls="collapse-{{ id }}-lft">
                {{ publication.title }}
            </button>
        </div>
        <div id="collapse-{{ id }}-lft"
             class="accordion-collapse collapse"
             role="region"
             data-bs-parent="#collapseDiv-{{ id }}-lft"
             aria-labelledby="heading-{{ id }}-lft">
            <div class="accordion-body">
                <p>{% include "includes/edit_page_publication.html" with item=page_publication %}</p>
                {% include "blocks/unical_publication_full_view_light.html" with publication=publication %}
            </div>
        </div>
    </div>
</div>
