{% extends "department.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}
{% load unicms_template_unical %}


{% block analytics_value %}
{% endblock analytics_value %}

{% block custom_style %}
<link rel="shortcut icon" href="{% unicms_template_unical_static_path 'images/favicon/favicon-32x32.png' %}">
<link rel="stylesheet" href="{% unicms_template_unical_static_path 'css/unicms_unical.css' %}" type="text/css">
<link rel="stylesheet" href="{% unicms_template_unical_static_path 'css/unicms_exbriner.css' %}" type="text/css">
<link rel="stylesheet" href="{% unicms_template_unical_static_path 'css/colors/unicms_exbriner.css' %}" type="text/css">
{% endblock custom_style %}

{% block page_meta_description %}{% if webpath.meta_description %}{{ webpath.meta_description }}{% else %}{% trans "EXBRINER Project (Horizon Europe/Marie Skłodowska-Curie Actions/Doctoral Networks, call: HORIZON-MSCA-2021-DN-01)" %}{% endif %}{% endblock page_meta_description %}
{% block page_meta_keywords %}{% if webpath.meta_keywords %}{{ webpath.meta_keywords }}{% else %}ExBrineR{% endif %}{% endblock page_meta_keywords %}

{% block header_slim_wrapper %}
{% settings_value "MAIN_DOMAIN" as cms_main_domain %}
<div class="it-header-slim-wrapper">
    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="it-header-slim-wrapper-content">
                    <small class="text-white">Call HORIZON – MSCA – 2021 – DN - Start Date 2022 | 10 | 01</small>
                    {% if request.user.is_staff %}
                    {% include "components/italia_editorialboard_frontend_menu.html" %}
                    {% endif %}
                </div>
            </div>
        </div>
    </div>
</div>
<a href="/" aria-label="{% trans 'University of Calabria' %}">
    <div class="it-header-center-wrapper d-lg-none h-auto pt-4">
        {% block unical_mobile_logo %}
            {% block header_slim_mobile_org_name_side %}
            <div class="col-5">
                <image src="{% unicms_template_unical_static_path 'images/logos/exbriner.png' %}" class="mw-100" />
            </div>
            <div class="col-5 offset-2">
                <image src="{% unicms_template_unical_static_path 'images/logos/eu_funded.svg' %}" class="mw-100" />
            </div>
            {% endblock header_slim_mobile_org_name_side %}
        {% endblock unical_mobile_logo %}
    </div>
</a>
{% endblock header_slim_wrapper %}

{% block header_center_right_zone %}
<div class="it-right-zone col-12 col-lg-4 d-none d-lg-block">
    <div class="row w-100">
        <div class="col-2 offset-10 offset-md-2 col-md-10">
            <image src="{% unicms_template_unical_static_path 'images/logos/eu_funded.svg' %}" class="mw-100" />
        </div>
    </div>
</div>
{% endblock header_center_right_zone %}

<!-- Logo in Header -->
{% block header_brand_wrapper %}
<div class="it-brand-wrapper col-lg-4 col-12">
    <a href="{% block header_center_url %}#{% endblock header_center_url %}">
        {% block header_center_logo %}
        <div class="d-none d-lg-flex col-lg-12 px-0 department_logo_lg">
            {% block header_center_logo_side %}
            <image src="{% unicms_template_unical_static_path 'images/logos/exbriner.png' %}" class="h-100" />
            {% endblock header_center_logo_side %}
        </div>
        {% endblock header_center_logo %}

        {% block header_brand_text %}
        {% endblock header_brand_text %}
    </a>
</div>
{% endblock header_brand_wrapper %}

{% block unical_header_languages %}
<div class="dark-grey-background py-2">
    <div class="text-center px-3">
        <div class="row">
            <div class="col">
                <b>Next-generation membrane technologies for sustainable exploitation of
    seawater brine resources: transition towards a circular blue industry</b>
            </div>
        </div>
    </div>
</div>
{% endblock unical_header_languages %}

{% block department_contacts %}
<div class="col-12 col-lg-3">
    <div class="mb-3">
        <image src="{% unicms_template_unical_static_path 'images/logos/exbriner.png' %}"
               class="w-100 h-100"
               alt="{% trans 'Department of Economics, Statistics and Finance' %}"/>
    </div>
    <p class="mb-4">
        Via P. Bucci
        <br>
        87036 Arcavacata di Rende (CS)
        <br>
        <a class="text-white" href="mailto:dipartimento.desf@pec.unical.it" title="dipartimento.desf@pec.unical.it">dipartimento.desf@pec.unical.it</a>
        <br>
        <a class="text-white" href="mailto:protocollo.desf@unical.it" title="protocollo.desf@unical.it">protocollo.desf@unical.it</a>
        <br>
        +39 0984 492434
        <br>
        +39 0984 492422
    </p>
</div>
{% endblock department_contacts %}

{% block footer_top %}
<div class="container text-center text-lg-start">
    <ul class="list-inline social py-4 mt-2 mb-0">
        <li class="list-inline-item">
            <a class="p-2" href="https://www.facebook.com/profile.php?id=100088359406451" target="_blank" rel="noopener noreferrer" title="Facebook">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-facebook-square"></use>
                </svg><span class="visually-hidden">Facebook</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://www.instagram.com/exbriner_eu/" target="_blank" rel="noopener noreferrer" title="Instagram">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-instagram"></use>
                </svg><span class="visually-hidden">Instagram</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://twitter.com/exbriner" target="_blank" rel="noopener noreferrer" title="Twitter">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-twitter"></use>
                </svg><span class="visually-hidden">Twitter</span>
            </a>
        </li>
    </ul>
</div>
{% endblock footer_top %}

{% block footer_bottom %}
<div class="it-footer-main clearfix py-4 border-white border-top unical-secondary-footer">
    <div class="container">
        <section>
            {% block footer_bottom_content %}
            <div class="row">
                <div class="col-12 col-lg-2">
                    <img src="{% unicms_template_unical_static_path 'images/logos/eu_funded_white.svg' %}" alt="EU" height="40" />
                </div>
                <div class="col-12 col-lg-10 mt-3 mt-lg-0">
                    The project EXBRINER — HORIZON-MSCA-DN-2021 has received funding
                    from the European Union’s Horizon Europe research and innovation programme
                    under the Marie Sklodowska-Curie grant agreement No 101072449.
                </div>
            </div>
            {% endblock footer_bottom_content %}
        </section>
    </div>
</div>
{% endblock footer_bottom %}
