ADDRESSBOOK_LINK = ''
DEPARTMENT_ADDRESSBOOK_LINK = ''
UNICAL_PUBLICATION_CAROUSEL_ITEMS = 3

# CDN FOR STATICS
UNICMS_TEMPLATE_UNICAL_USE_CDN = False
UNICMS_TEMPLATE_UNICAL_CDN = 'https://cdn.jsdelivr.net/gh/UniversitaDellaCalabria/unicms-template-unical@1.6.0/src/unicms_template_unical/static'
