/** * Università della Calabria * Portale Style SCSS */
@font-face {
  font-family: TitilliumWeb-Black;
  src: url(../fonts/TitilliumWeb-Black.ttf);
  font-display: swap;
}
/** * Generic elements */
a {
  cursor: pointer;
}

img {
  max-width: 100%;
}

/** * Header Center Wrapper */
@media (min-width: 992px) {
  .it-header-center-wrapper {
    height: 130px;
  }
}
/** * Logo */
.it-header-center-wrapper .it-header-center-content-wrapper .it-brand-wrapper a .img {
  width: 100%;
}
/** * Header Navbar Wrapper */
/* Desktops and laptops ----------- */
@media (min-width: 992px) {
  .it-header-center-wrapper .it-header-center-content-wrapper .it-brand-wrapper a .logo_icon image {
    width: 100%;
  }
}
/* Others than desktop ----------- */
@media (max-width: 991px) {
  .it-header-center-wrapper .it-header-center-content-wrapper .it-brand-wrapper a .logo_icon image {
    height: 100%;
  }
}
a {
  text-decoration: underline;
}
a:hover, a:active {
  text-decoration: none;
}
/** only visited **/
a.no-color, ol.breadcrumb a {
  text-decoration: none;
}
a.no-color:hover, a.no-color:active, ol.breadcrumb a:hover, ol.breadcrumb a:active {
  text-decoration: underline;
}
/** end only visited **/
.super-bold {
  font-family: TitilliumWeb-Black;
}
.lighter {
  font-weight: lighter;
}
.bigger-font {
  font-size: 1.5rem;
}
input.top-input {
  height: 1.7rem;
  width: 100%;
}
.it-hero-wrapper .it-hero-text-wrapper h1 {
  padding: 1rem;
  font-family: TitilliumWeb-Black;
}
.card.card-bg {
  margin-left: 0;
  margin-right: 0;
}
.card .card-body .category-top {
  text-transform: none;
}
.card .etichetta {
  font-size: 1rem;
  text-transform: lowercase;
  margin-bottom: 15px;
  display: block;
}
.card-title {
  font-weight: bold;
}
.card .card-title {
  line-height: 1;
}
.card .card-body .card-text {
  font-family: Titillium Web;
  font-size: 16px;
}
.nav-mobile {
  width: 100%;
}
/*
.it-header-slim-wrapper .container {
  padding-left: 0;
  padding-right: 0;
}
*/
@media (min-width: 992px){
    .it-header-slim-wrapper .it-header-slim-wrapper-content {
      padding: 0;
    }
}
.badge-grey-unical {
  font-weight: 500;
}
.badge-left-text-unical {
  text-align: left;
  white-space: inherit;
}
a .badge-grey-unical:hover, a .badge-grey-unical.selected {
  text-decoration: none;
}
.square-corners {
  border-radius: 0;
}
.publication-hero {
  min-height: 300px;
}
.breadcrumb-container {
  padding-top: 15px;
  padding-bottom: 15px;
  font-size: 0.78rem;
}
.breadcrumb-container .breadcrumb {
  margin-bottom: 0;
}
.it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper {
  margin-top: -45px;
}
/** * Medium with */
@media (min-width: 992px) {
  .it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper {
    padding-top: 1.7rem;
    margin-top: 0;
  }
  .it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper nav {
    padding-left: 0;
    padding-right: 0;
  }
  .it-header-center-wrapper .it-header-center-content-wrapper {
    padding-left: 0;
    padding-right: 0;
  }
  .navbar .navbar-collapsable .navbar-nav li.nav-item {
    font-size: 1.2rem;
  }
}
/** * De Marco */
.menu-wrapper {
  z-index: 1 !important;
}
.owl-carousel {
  z-index: 0;
}
.owl-nav {
  display: none;
}
.owl-carousel-cards .owl-stage, .custom-unical .owl-stage {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}
.owl-carousel-cards .owl-item, .custom-unical .owl-item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: grid;
  height: auto !important;
}
.custom-unical .card-wrapper {
  padding-bottom: 16px;
}
.it-carousel-wrapper.custom-unical .owl-carousel .owl-dots {
  display: none;
}
.navbar .navbar-collapsable .navbar-nav li a.nav-link {
  border-bottom: none !important;
}
.it-carousel-wrapper .owl-stage-outer {
  padding-top: 0px;
  padding-bottom: 0;
}
/** * Main Menu */
.dropdown-menu {
  padding: 16px 2px !important;
}
.navbar .dropdown-menu:before {
  display: none;
}
.link-list-wrapper ul li a {
  line-height: inherit;
}
@media (min-width: 992px) {
  .navbar .nav-item .dropdown-menu {
    display: none;
  }
  .navbar .nav-item:hover .nav-link {
    text-decoration: underline;
  }
  .navbar .nav-item:hover .dropdown-menu {
    display: block;
  }
  .navbar .nav-item .dropdown-menu {
    margin-top: 0;
  }
}
@media (max-width: 991px) {
  .navbar .nav-item a.nav-link {
    float: left;
  }
  .navbar .nav-item span.megamenu-dropdown-arrow {
    float: right;
    margin: 10px;
  }
  .navbar .nav-item .dropdown-menu {
    float: left;
  }
}
.accordion.accordion-left-icon .accordion-header .accordion-button:before {
  flex: none;
}

.accordion-left-icon .accordion-header [data-bs-toggle=collapse][aria-expanded=false]:before,
.accordionUnicalRightIcon .accordion-header [data-bs-toggle=collapse][aria-expanded=false]:after { content: url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIGlkPSJpdC1wbHVzLWNpcmNsZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgaWQ9IkxpdmVsbG9fMTMiIGRhdGEtbmFtZT0iTGl2ZWxsbyAxMyI+CiAgICA8cGF0aCAgZmlsbD0iIzM4MzgzOCIgZD0iTTEyLjQgMTEuNWg0LjV2MWgtNC41VjE3aC0xdi00LjVINi45di0xaDQuNVY3aDF6bTkuNi41QTEwIDEwIDAgMTExMiAyYTEwIDEwIDAgMDExMCAxMHptLTEgMGE5IDkgMCAxMC05IDkgOSA5IDAgMDA5LTl6Ii8+PC9nPjwvc3ZnPg==") !important; margin-bottom: 0; }

.accordion-left-icon .accordion-header [data-bs-toggle=collapse][aria-expanded=true]:before,
.accordionUnicalRightIcon .accordion-header [data-bs-toggle=collapse][aria-expanded=true]:after { content: url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIGlkPSJpdC1wbHVzLWNpcmNsZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgaWQ9IkxpdmVsbG9fMTMiIGRhdGEtbmFtZT0iTGl2ZWxsbyAxMyI+CiAgICA8cGF0aCAgZmlsbD0iIzM4MzgzOCIgZD0iTTYuOSAxMS41aDEwdjFoLTEwek0yMiAxMkExMCAxMCAwIDExMTIgMmExMCAxMCAwIDAxMTAgMTB6bS0xIDBhOSA5IDAgMTAtOSA5IDkgOSAwIDAwOS05eiIvPjwvZz48L3N2Zz4=") !important; margin-bottom: 0; }

.accordion-left-icon .accordion-header-white [data-bs-toggle=collapse][aria-expanded=false]:before { content: url("data:image/svg+xml;base64,PCEtLSBSZXBsYWNlIHRoZSBjb250ZW50cyBvZiB0aGlzIGVkaXRvciB3aXRoIHlvdXIgU1ZHIGNvZGUgLS0+Cgo8c3ZnIHZpZXdCb3g9IjAgMCAyNCAyNCIgaWQ9Iml0LXBsdXMtY2lyY2xlIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgo8ZyBpZD0iTGl2ZWxsb18xMyIgZGF0YS1uYW1lPSJMaXZlbGxvIDEzIj4KICAgIDxwYXRoICBmaWxsPSIjZmZmZmZmIiBkPSJNMTIuNCAxMS41aDQuNXYxaC00LjVWMTdoLTF2LTQuNUg2Ljl2LTFoNC41VjdoMXptOS42LjVBMTAgMTAgMCAxMTEyIDJhMTAgMTAgMCAwMTEwIDEwem0tMSAwYTkgOSAwIDEwLTkgOSA5IDkgMCAwMDktOXoiLz48L2c+PC9zdmc+") !important; margin-bottom: 0; }
.accordion-left-icon .accordion-header-white [data-bs-toggle=collapse][aria-expanded=true]:before { content: url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIGlkPSJpdC1wbHVzLWNpcmNsZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgaWQ9IkxpdmVsbG9fMTMiIGRhdGEtbmFtZT0iTGl2ZWxsbyAxMyI+CiAgICA8cGF0aCAgZmlsbD0iI2ZmZmZmZiIgZD0iTTYuOSAxMS41aDEwdjFoLTEwek0yMiAxMkExMCAxMCAwIDExMTIgMmExMCAxMCAwIDAxMTAgMTB6bS0xIDBhOSA5IDAgMTAtOSA5IDkgOSAwIDAwOS05eiIvPjwvZz48L3N2Zz4=") !important; margin-bottom: 0; }

.accordion-left-icon .accordion-header-href [data-bs-toggle=collapse][aria-expanded=false]:before { content: url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIGlkPSJpdC1wbHVzLWNpcmNsZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgaWQ9IkxpdmVsbG9fMTMiIGRhdGEtbmFtZT0iTGl2ZWxsbyAxMyI+CiAgICA8cGF0aCAgZmlsbD0iIzM4MzgzOCIgZD0ibSAxMy45IDcuNyA0LjMgNC4zLTQuMyA0LjMtLjctLjcgMy4xLTMuMQpIIDcKdiAtMQpoIDkuMgpsIC0zLTMuMS43LS43CnoKCk0gMjIgMTIKYyAwIDUuNS00LjUgMTAtMTAgMTAKUyAyIDE3LjUgMiAxMiA2LjUgMiAxMiAyCnMgMTAgNC41IDEwIDEwCnoKCm0gLTEgMApjIDAtNS00LTktOS05CnMgLTkgNC05IDkgNCA5IDkgOSA5LTQgOS05CnoiLz48L2c+PC9zdmc+") !important; margin-bottom: 0; }

.accordion-header .no-icon:before,
.accordion-header .no-icon:after { display: none !important; }

.accordion-header button[aria-expanded="true"]::before {
  height: 1.5rem !important;
  width: 1.5rem !important;
}
.department_logo_lg {
  height: 63px;
}
select.form-control {
  border-width: 1px;
  appearance: auto;
}
.it-header-center-wrapper {
  /* WebKit, Blink, Edge */
}
.it-header-center-wrapper ::-webkit-input-placeholder {
  color: inherit;
}
.it-header-center-wrapper :-moz-placeholder {
  /* Mozilla Firefox 4 to 18 */
  color: inherit;
  opacity: 1;
}
.it-header-center-wrapper ::-moz-placeholder {
  /* Mozilla Firefox 19+ */
  color: inherit;
  opacity: 1;
}
.it-header-center-wrapper :-ms-input-placeholder {
  /* Internet Explorer 10-11 */
  color: inherit;
}
.it-header-center-wrapper ::-ms-input-placeholder {
  /* Microsoft Edge */
  color: inherit;
}
.it-header-center-wrapper ::placeholder {
  /* Most modern browsers support this now. */
  color: inherit;
}
.col img {
  max-width: 100%;
}
.unical-alert ul {
  margin-bottom: 0;
}
@media (max-width: 768px) {
  .full-width-mobile {
    width: 100%;
  }
}
.card-columns-2 {
  column-count: 2;
}
@media (max-width: 992px) {
  .card-columns-2 {
    column-count: 1;
  }
}
/** * fix publication tables images size */
figure.table table td figure.image {
  text-align: center;
}
figure.table table td figure.image img {
  width: 80px;
  max-width: 80px;
}
.it-footer {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
}
/** * UniCal Hero slider */
@media (max-width: 991px) {
  .it-hero-text-wrapper.unical-hero-text-wrapper {
    padding: 26px;
  }
}
@media (min-width: 992px) {
  .it-hero-text-wrapper.unical-hero-text-wrapper {
    padding: 120px 26px 168px;
  }
}
.it-hero-wrapper .it-hero-text-wrapper h5.unical-hero-preheading {
  padding: 20px;
  position: inherit;
  text-transform: inherit;
  width: fit-content;
  font-weight: bold;
  margin-bottom: 24px;
}
.it-hero-wrapper .it-hero-text-wrapper h6.unical-hero-preheading {
  padding: 10px 20px;
  position: inherit;
  text-transform: inherit;
  width: fit-content;
  font-weight: bold;
  margin-bottom: 12px;
}
.it-hero-wrapper .it-hero-text-wrapper h1.unical-hero-heading, .it-hero-wrapper .it-hero-text-wrapper h2.unical-hero-heading, .it-hero-wrapper .it-hero-text-wrapper h3.unical-hero-heading, .it-hero-wrapper .it-hero-text-wrapper h4.unical-hero-heading {
  padding: 1rem;
  font-family: Lora;
  font-style: italic;
  width: fit-content;
}
.it-hero-wrapper .it-hero-text-wrapper h1.unical-hero-description, .it-hero-wrapper .it-hero-text-wrapper h2.unical-hero-description, .it-hero-wrapper .it-hero-text-wrapper h3.unical-hero-description, .it-hero-wrapper .it-hero-text-wrapper h4.unical-hero-description {
  padding: 1rem;
  font-family: Lora;
  font-style: italic;
  width: fit-content;
}
.it-hero-wrapper.unical-hero-wrapper-slim {
  min-height: 300px;
}
@media (min-width: 992px) {
  .it-hero-wrapper.unical-hero-wrapper-slim .it-hero-text-wrapper.unical-hero-text-wrapper {
    padding: 20px 26px;
  }
}
.it-footer-main {
  font-size: 15px;
}
.it-footer-main h4 span {
    font-size: 16px;
    text-transform: uppercase;
}
@media (max-width: 991px) {
  .it-footer-main .link-list-wrapper ul li a {
    padding: 24px 0;
  }
}
/** Owl CLS fix */
.owl-carousel {
  display: block;
}
.owl-carousel .slide-owl-wrap:not(:first-child) {
  display: none;
}
.owl-carousel img {
  width: 100%;
}
@media (min-width: 992px) {
  .ps-lg-2, .px-lg-2 {
    padding-left: 8px !important;
  }
}
@media (min-width: 992px) {
  .pe-lg-1, .px-lg-1 {
    padding-right: 4px !important;
  }
}
/** Negative margin fix */
.ms-n1 {
  margin-left: -4px;
}
.me-n1 {
  margin-right: -4px;
}
.mx-n1 {
  margin-left: -4px;
  margin-right: -4px;
}
.ms-n2 {
  margin-left: -8px;
}
.me-n2 {
  margin-right: -8px;
}
.mx-n2 {
  margin-left: -8px;
  margin-right: -8px;
}
.ms-n3 {
  margin-left: -16px;
}
.me-n3 {
  margin-right: -16px;
}
.mx-n3 {
  margin-left: -16px;
  margin-right: -16px;
}
.ms-n4 {
  margin-left: -24px;
}
.me-n4 {
  margin-right: -24px;
}
.mx-n4 {
  margin-left: -24px;
  margin-right: -24px;
}
.ms-n5 {
  margin-left: -48px;
}
.me-n5 {
  margin-right: -48px;
}
.mx-n5 {
  margin-left: -48px;
  margin-right: -48px;
}
.mt-n1 {
  margin-top: -4px;
}
.mt-n2 {
  margin-top: -8px;
}
.mt-n3 {
  margin-top: -16px;
}
.mt-n4 {
  margin-top: -24px;
}
.mt-n5 {
  margin-top: -48px;
}
/** Gutter to 12px */
.row {
  --bs-gutter-x: 12px;
}
.input-group-append .btn, .input-group-prepend .btn {
  z-index: inherit;
}

.dark-brightness .it-hero-text-wrapper.unical-hero-text-wrapper {
/*
  backdrop-filter: brightness(50%);
*/
  backdrop-filter: brightness(50%);
  padding: 20px;
}
@media (max-width: 991px) {
  .dark-brightness .it-hero-text-wrapper.unical-hero-text-wrapper {
    margin: 26px;
  }
}
@media (min-width: 992px) {
  .dark-brightness .it-hero-text-wrapper.unical-hero-text-wrapper {
    margin: 120px 26px;
  }
}
