<script src="https://cdnjs.cloudflare.com/ajax/libs/brython/3.9.0/brython.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/brython/3.9.0/brython_stdlib.min.js"></script>

<script type="text/javascript">
    // brython init
    document.addEventListener('DOMContentLoaded', function() {
        brython({debug: 1});
    }, false);
</script>
