{% load i18n %}
{% load static %}

{% load unicms_template_unical %}

{% load_same_level_items exclude_item=False as items %}

{% include "unical_menu_collapse.html" with items=items.items current=items.current title=items.parent.name %}
