{% extends "blocks/unical_menu_grey_box_generic.html" %}

{% load i18n %}

{% block icon %}
<div class="col-2" style="font-size: x-large">
    <span class="ps-1" style="font-weight: 400" title="{% trans 'Digital services' %}">
        @
    </span>
</div>
{% endblock %}

