{% load i18n %}
{% load static %}


<h4>{% trans "Links" %}</h4>
<ul class="list-unstyled">
{% for link in publication.related_links %}
    <li class="mb-3">
        <a href="{{ link.url }}" target="_blank" rel="noopener" rel="noreferrer">
            <svg class="icon icon-xs">
                <use xlink:href="{% static 'svg/sprites.svg' %}#it-link"></use>
            </svg>
            {{ link.name }}
        </a>
    </li>
{% endfor %}
</ul>
