{% extends "blocks/unical_publication_full_view.html" %}

{% load i18n %}
{% load static %}


{% block publication_title %}
<h4>{{ publication.title }}</h4>
{% endblock publication_title %}

{% block publication_attachments %}
{% endblock publication_attachments %}

{% block publication_links %}
{% endblock publication_links %}
