{% extends 'bases/error-page.html' %}

{% load i18n %}

{% block error_type %}
    {% trans "Error 404" %}
{% endblock error_type %}

{% block error_description %}
    <p>{% trans "Page or Resource not found" %}</p>
    <p>{% trans "You may have clicked on an invalid link or misspelled the page address." %}</p>
    <p>{% trans "You can search for it starting from the home page or it could be reachable on the previous version of the website which can be found at www2.unical.it" %}</p>
    <hr>
    <p>{% trans "If you keep getting this error even though you are trying to reach the home page, clear your browser cache." %}</p>
{% endblock error_description %}

{% block other_buttons %}
<a role="button" class="btn btn-secondary ms-lg-2 d-block d-lg-inline mt-2 mt-lg-0" href="https://www2.unical.it{{ request.path }}" target="_blank" rel="noopener noreferrer">
    www2.unical.it
</a>
{% endblock other_buttons %}
