<!-- Extends default Bootstrap Unical Italia template -->
<!--
base-setup.html
bootstrap-italia-base.html
-->
{% extends 'bases/unicms_italia.html' %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}
{% load unicms_template_unical %}


<!-- Custom extra head params -->
{% block extra_head %}
    {% block custom_style %}
    <link rel="shortcut icon" href="{% unicms_template_unical_static_path 'images/favicon/favicon-32x32.png' %}">
    <link rel="stylesheet" href="{% unicms_template_unical_static_path 'css/unicms_unical.css' %}" type="text/css">
    <link rel="stylesheet" href="{% unicms_template_unical_static_path 'css/colors/unicms_unical.css' %}" type="text/css">
    {% endblock custom_style %}

    {% block head_inits %}
        {{ block.super }}
    {% endblock head_inits %}

    {% block html_head %}
        {{ block.super }}
    {% endblock html_head %}

    {% block social_tags %}
        {{ block.super }}
    {% endblock social_tags %}
{% endblock extra_head %}

<!-- Meta Description (for all pages if not overrided) -->
{% block page_meta_description %}{% if webpath.meta_description %}{{ webpath.meta_description }}{% else %}{% trans "Official University of Calabria website" %}{% endif %}{% endblock page_meta_description %}
{% block page_meta_keywords %}{% if webpath.meta_keywords %}{{ webpath.meta_keywords }}{% else %}UniCal{% endif %}{% endblock page_meta_keywords %}

{% block header_brand_wrapper %}
<div class="d-none d-lg-inline col-lg-6">
    {{ block.super }}
</div>
{% endblock header_brand_wrapper %}

<!-- Logo in Header -->
{% block header_center_logo %}
<div class="d-none d-lg-flex col-lg-12 px-0">
    <image src="{% unicms_template_unical_static_path 'images/logo_unical_white.svg' %}"
           class="w-100"
           alt="{% trans 'University of Calabria' %}"
           style="aspect-ratio: 11,15"/>
    <image src="{% unicms_template_unical_static_path 'images/logos/HRS4R.svg' %}"
           class="ms-3"
           style="width: 8%; aspect-ratio: 1"
           alt="{% trans 'HRS4R' %}"/>
</div>
{% endblock header_center_logo %}

{% block header_brand_text %}
{% endblock header_brand_text %}

{% block header_slim_wrapper %}
    {% if request.user.is_staff %}
    {{ block.super }}
    {% endif %}
    <a href="{% block header_mobile_center_url %}/{% endblock header_mobile_center_url %}" aria-label="{% trans 'University of Calabria' %}">
        <div class="it-header-center-wrapper d-lg-none h-auto pt-4">
            {% block unical_mobile_logo %}
            <image src="{% unicms_template_unical_static_path 'images/logo_unical_white.svg' %}"
                   class="w-100 h-100 d-md-none"
                   alt="{% trans 'University of Calabria' %}"
                   style="aspect-ratio: 11,15"/>
            <image src="{% unicms_template_unical_static_path 'images/logos/HRS4R.svg' %}"
                   class="d-md-none ms-1"
                   style="width: 8%; aspect-ratio: 1"
                   alt="{% trans 'HRS4R' %}"/>
            <image src="{% unicms_template_unical_static_path 'images/logo_unical_white.svg' %}"
                   class="w-75 h-100 d-none d-md-block"
                   alt="{% trans 'University of Calabria' %}"
                   style="aspect-ratio: 11,15"/>
            <image src="{% unicms_template_unical_static_path 'images/logos/HRS4R.svg' %}"
                   class="d-none d-md-block ms-3"
                   style="width: 6%; aspect-ratio: 1"
                   alt="{% trans 'HRS4R' %}"/>
            {% endblock unical_mobile_logo %}
        </div>
    </a>
{% endblock header_slim_wrapper %}

{% block header_slim_right_zone %}
{% endblock header_slim_right_zone %}

{% block header_mobile_arrow %}
{% endblock header_mobile_arrow %}

{% block header_center_wrapper_columns %}
col-10 offset-2 col-lg-12 offset-lg-0
{% endblock header_center_wrapper_columns %}

{% block header_center_right_zone %}

{% settings_value "CMS_PATH_PREFIX" as cms_path_prefix %}
{% settings_value "ADDRESSBOOK_LINK" as addressbook_link %}

<div class="it-right-zone col-12 col-lg-5 offset-lg-1">
    <div class="row w-100">

        {% comment %}
        CENSIS MOD
        <div class="col-2 offset-6 offset-md-1 col-md-8">
        {% endcomment %}
        <div class="col-2 offset-8 offset-md-1 col-md-10">

            {% settings_value "CMS_PATH_PREFIX" as cms_path_prefix %}
            <a href='/{{ cms_path_prefix }}search/' aria-label="{% trans 'Search' %}">
                <svg class="icon d-md-none icon-sm icon-light" aria-labelledby="search_mobile">
                    <title id="search_mobile">
                        {% trans 'Search' %}
                    </title>
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-search"></use>
                </svg>
            </a>
            <div class="row d-none d-md-flex">
                <div class="col-2 col-lg-3 text-end">
                    <svg class="icon icon-md icon-light" aria-labelledby="search">
                        <title id="search">
                            {% trans 'Search' %}
                        </title>
                        <use xlink:href="{% static 'svg/sprites.svg' %}#it-search"></use>
                    </svg>
                </div>
                <div class="col-9 col-lg-8">
                    <input id="search-engine-input" type="text" placeholder="{% trans 'Search' %}..." class="top-input" />
                </div>
            </div>
        </div>

        <div class="col-2 col-md-1 text-center">
            <a href="{% block addressbook_link %}{{ addressbook_link }}{% endblock addressbook_link %}">
                <img src="{% unicms_template_unical_static_path 'images/addressbook.svg' %}"
                     style="height: 32px; width: 38px;"
                     class="d-none d-lg-block"
                     alt="{% trans 'Address book' %}"
                     title="{% trans 'Address book' %}"
                     loading="lazy">
                <img src="{% unicms_template_unical_static_path 'images/addressbook.svg' %}"
                     style="height: 24px; width: 28px;"
                     class="d-lg-none"
                     alt="{% trans 'Address book' %}"
                     title="{% trans 'Address book' %}"
                     loading="lazy">
            </a>
        </div>

        {% comment %}
        CENSIS MOD
        <div class="col-2 text-center">
            <div class="nav-item dropdown">
                <a class="nav-link dropdown-toggle p-0 text-center"
                   title="{% trans 'Language' %}"
                   href="#"
                   data-toggle="dropdown"
                   aria-expanded="false">
                    <span>{{ request.LANGUAGE_CODE }}</span>
                </a>
                <div class="dropdown-menu">
                    <div class="row">
                        <div class="col-12">
                            <div class="link-list-wrapper">
                                <ul class="link-list">
                                    {% language_menu as language_urls %}
                                    {% for cod,params in language_urls.items %}
                                    <li><a class="cursor: pointer;; list-item" href="{{ params.1 }}"><span>{{ params.0 }}</span></a></li>
                                    {% endfor %}
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        {% endcomment %}

        {% comment %}
        <div class="col-3 col-md-2 text-center">
            {% if request.user.is_authenticated %}
            <a href="{% url 'logout' %}" class="nav-link p-0">
                <span>
                    {% trans "Logout" %}
                </span>
            </a>
            {% else %}
            <a href="{% url 'login' %}" class="nav-link p-0">
                <span>
                    {% trans "Login" %}
                </span>
            </a>
            {% endif %}
        </div>
        {% endcomment %}
    </div>
</div>
{% endblock header_center_right_zone %}

<!-- Main Menu -->
{% block main_menu %}

{% block unical_header_languages %}
<div class="dark-grey-background py-2">
    <div class="container text-center text-lg-end">
        <div class="row">
            <div class="col">
                {% language_menu as language_urls %}
                {% for cod,params in language_urls.items %}
                    {% load_lang_flag cod as flag_path %}
                    <a href="{{ params.1 }}" style="cursor: pointer;" title="{{ params.0 }}">
                        <img src="{{ flag_path }}" alt="{{ params.0 }}" style="width: 27px; height: 27px;" class="me-2"/>
                    </a>
                {% endfor %}
                <a href="/chinese/?lang=en" style="cursor: pointer;" title="{% trans 'Chinese' %}">
                    <img alt="{% trans 'Chinese' %}" src="{% unicms_template_unical_static_path '/images/flags/zh.svg' %}" style="cursor: pointer; width: 27px; height: 27px;" class="me-2"/>
                </a>
                <a href="/francais/?lang=en" style="cursor: pointer;" title="{% trans 'French' %}">
                    <img alt="{% trans 'French' %}" src="{% unicms_template_unical_static_path '/images/flags/fr.svg' %}" style="cursor: pointer; width: 27px; height: 27px;" class="me-2"/>
                </a>
                <a href="/portugues/?lang=en" style="cursor: pointer;" title="{% trans 'Portuguese' %}">
                    <img alt="{% trans 'Portuguese' %}" src="{% unicms_template_unical_static_path '/images/flags/pt.svg' %}" style="cursor: pointer; width: 27px; height: 27px;" class="me-2"/>
                </a>
                <a href="/espanol/?lang=en" style="cursor: pointer;" title="{% trans 'Espanol' %}">
                    <img alt="{% trans 'Espanol' %}" src="{% unicms_template_unical_static_path '/images/flags/es.svg' %}" style="cursor: pointer; width: 27px; height: 27px;" class="me-2"/>
                </a>
                <a href="/arabo/?lang=en" style="cursor: pointer;" title="{% trans 'Arabic' %}">
                    <img alt="{% trans 'Arabic' %}" src="{% unicms_template_unical_static_path '/images/flags/ar.svg' %}" style="cursor: pointer; width: 27px; height: 27px;" class="me-2"/>
                </a>
                <a href="/russo/?lang=en" style="cursor: pointer;" title="{% trans 'Russian' %}">
                    <img alt="{% trans 'Russian' %}" src="{% unicms_template_unical_static_path '/images/flags/ru.svg' %}" style="cursor: pointer; width: 27px; height: 27px;" />
                </a>
            </div>
        </div>
    </div>
</div>
{% endblock unical_header_languages %}

<div class="it-header-navbar-wrapper">
    <div class="container">
        <div class="row">
            <div class="col-12">
                <nav class="navbar navbar-expand-lg has-megamenu" aria-label="{% trans 'Main menu' %}">
                    <button class="custom-navbar-toggler"
                            type="button"
                            aria-controls="nav10"
                            aria-expanded="false"
                            aria-label="{% trans 'Show/Hide menu' %}"
                            data-bs-toggle="navbarcollapsible"
                            data-bs-target="#nav10">
                        <svg class="icon">
                            <use xlink:href="{% static 'svg/sprites.svg' %}#it-burger"></use>
                        </svg>
                    </button>
                    <div class="navbar-collapsable" id="nav10" style="display: none;">
                        <div class="overlay" style="display: none;"></div>
                        <div class="close-div">
                            <button class="btn close-menu" type="button">
                                <svg class="icon">
                                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-close-big"></use>
                                </svg>
                                <span class="visually-hidden">
                                    {% trans "Close" %}
                                </span>
                            </button>
                        </div>
                        <div class="menu-wrapper">
                            <ul class="navbar-nav">
                                {% block menu_main %}
                                    <!-- LOAD menu Blocks -->
                                    {% load_blocks section='menu-1' %}
                                {% endblock menu_main %}
                            </ul>
                        </div>
                    </div>
                </nav>
            </div>
        </div>
    </div>
</div>

{% endblock main_menu %}

{% block section_2_classes %}
    dark-grey-background py-5
{% endblock section_2_classes %}

{% block footer_top_section %}
{% endblock footer_top_section %}

{% block footer_top %}
<div class="container text-center text-lg-start">
    <ul class="list-inline social py-4 mt-2 mb-0">
        <li class="list-inline-item">
            <a class="p-2" href="https://it-it.facebook.com/unicalufficiale/" target="_blank" rel="noopener noreferrer" title="Facebook">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-facebook-square"></use>
                </svg><span class="visually-hidden">Facebook</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://twitter.com/UniCalPortale?ref_src=twsrc%5Egoogle%7Ctwcamp%5Eserp%7Ctwgr%5Eauthor" target="_blank" rel="noopener noreferrer" title="Twitter">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-twitter"></use>
                </svg><span class="visually-hidden">Twitter</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://www.linkedin.com/school/universit%C3%A0-della-calabria/" target="_blank" rel="noopener noreferrer" title="Linkedin">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-linkedin-square"></use>
                </svg><span class="visually-hidden">Linkedin</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://www.instagram.com/unical_official/" target="_blank" rel="noopener noreferrer" title="Instagram">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-instagram"></use>
                </svg><span class="visually-hidden">Instagram</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://www.youtube.com/@campusunical" target="_blank" rel="noopener noreferrer" title="YouTube">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-youtube"></use>
                </svg><span class="visually-hidden">Youtube</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://github.com/UniversitaDellaCalabria" target="_blank" rel="noopener noreferrer" title="Github">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-github"></use>
                </svg><span class="visually-hidden">Github</span>
            </a>
        </li>
    </ul>
</div>
{% endblock footer_top %}


<!-- Footer middle section with menu blocks -->
{% block footer_menu_section %}
<section>
    <div class="row" style="padding-top: 20px;">

        {% block first_column %}
        <div class="col-lg-3 col-sm-6 pb-2">
            <h4>
                <span>
                    {% trans 'UniCal for students' %}
                </span>
            </h4>
            <div class="link-list-wrapper">
                <ul class="footer-list link-list clearfix">
                    <li><a class="list-item" href="/campus/servizi/" title="{% trans 'Prospective students, Enrolled and Graduates' %}">{% trans 'Prospective students, Enrolled and Graduates' %}</a></li>
                    <li><a class="list-item" href="/didattica/offerta-formativa/" title="{% trans 'Educational offer' %}">{% trans 'Educational offer' %}</a></li>
                    <li><a class="list-item" href="/didattica/offerta-formativa/catalogo/" title="{% trans 'Study activities catalogue' %}">{% trans 'Study activities catalogue' %}</a></li>
                    <li><a class="list-item" href="/didattica/iscriversi-studiare-laurearsi/" title="{% trans 'Enroll, study and graduate' %}">{% trans 'Enroll, study and graduate' %}</a></li>
                    <li><a class="list-item" href="/didattica/diritto-allo-studio/" title="{% trans 'Right to study' %}">{% trans 'Right to study' %}</a></li>
                    <li><a class="list-item" href="/didattica/orientamento/" title="{% trans 'Orientation' %}">{% trans 'Orientation' %}</a></li>
                    <li><a class="list-item" href="/didattica/diritto-allo-studio/servizi-per-studenti-con-disabilita-e-dsa/" title="{% trans 'Students with disabilities/LDS' %}">{% trans 'Students with disabilities/LDS' %}</a></li>
                    <li><a class="list-item" href="/didattica/orientamento/counselling/" title="{% trans 'Psychological counseling' %}">{% trans 'Psychological counseling' %}</a></li>
                    <li><a class="list-item" href="http://careerservices.unical.it/" target="_blank" rel="noopener noreferrer" title="{% trans 'Career Service / Job Placement' %}">{% trans 'Career Service / Job Placement' %}</a></li>
                    <li><a class="list-item" href="/internazionale/studiare-all-estero/accordi-e-reti/accordi-internazionali/" title="{% trans 'International agreements and networks' %}">{% trans 'International agreements and networks' %}</a></li>
                    <li><a class="list-item" href="/didattica/offerta-formativa/formazione-insegnanti/" title="{% trans 'Teacher training courses' %}">{% trans 'Teacher training courses' %}</a></li>
                    <li><a class="list-item" href="/didattica/offerta-formativa/esami-di-stato/" title="{% trans 'State examinations' %}">{% trans 'State examinations' %}</a></li>
                </ul>
            </div>
        </div>
        {% endblock first_column %}

        {% block second_column %}
        <div class="col-lg-3 col-sm-6 pb-2">
            <h4>
                <span>
                    {% trans 'UniCal online' %}
                </span>
            </h4>
            <div class="link-list-wrapper">
                <ul class="footer-list link-list clearfix">
                    <li><a class="list-item" href="/front-office/" title="{% trans 'Online front-office' %}">{% trans 'Online front-office' %}</a></li>
                    <li><a class="list-item" href="https://ticket.unical.it/" target="_blank" rel="noopener noreferrer" title="{% trans 'Online ticket' %}">{% trans 'Online ticket' %}</a></li>
                    <li><a class="list-item" href="/servizi-ict" title="{% trans 'ITC Services' %}">{% trans 'ITC Services' %}</a></li>
                    <li><a class="list-item" href="/servizi-ict/servizi-digitali-studenti/accesso-wifi-ateneo/" title="{% trans 'Wi-Fi Services' %}">{% trans 'Wi-Fi Services' %}</a></li>
                    <li><a class="list-item" href="/servizi-ict/servizi-digitali-studenti/posta-elettronica-studenti/" title="{% trans 'Students webmail' %}">{% trans 'Students webmail' %}</a></li>
                    <li><a class="list-item" href="/servizi-ict/servizi-digitali-per-il-personale/posta-elettronica/" title="{% trans 'Employees webmail' %}">{% trans 'Employees webmail' %}</a></li>
                    <li><a class="list-item" href="/servizi-ict/servizi-digitali-studenti/credenziali-di-ateneo/" title="{% trans 'SPID / UniCal ID' %}">{% trans 'SPID / UniCal ID' %}</a></li>
                    <li><a class="list-item" href="/didattica/iscriversi-studiare-laurearsi/tasse-ed-esoneri/" title="{% trans 'Online Taxes / PagoPA' %}">{% trans 'Online Taxes / PagoPA' %}</a></li>
                    <li><a class="list-item" href="/servizi-ict/servizi-digitali-studenti/esse3-web/" title="{% trans 'Exam reservations - ESSE3' %}">{% trans 'Exam reservations - ESSE3' %}</a></li>
                    <li><a class="list-item" href="https://www.unical.it/esse3pa" target="_blank" rel="noopener noreferrer" title="{% trans 'ESSE3PA' %}">{% trans 'ESSE3PA' %}</a></li>
                    <li><a class="list-item" href="https://24cfu.unical.it/elearning/" target="_blank" rel="noopener noreferrer" title="{% trans 'e-Learning platform' %}">{% trans 'e-Learning platform' %}</a></li>
                    <li><a class="list-item" href="/web-radio" title="{% trans 'Web Radio' %}">{% trans 'Web Radio' %}</a></li>
                    <li><a class="list-item" href="/unical-magazine/" title="{% trans 'Online Magazine' %}">{% trans 'Online Magazine' %}</a></li>
                </ul>
            </div>
        </div>
        {% endblock second_column %}

        {% block third_column %}
        <div class="col-lg-3 col-sm-6 pb-2">
            <h4>
                <span>
                    {% trans 'Living on Campus' %}
                </span>
            </h4>
            <div class="link-list-wrapper">
                <ul class="footer-list link-list clearfix">
                    <li><a class="list-item" href="/organizzazione/strutture/dipartimenti/" title="{% trans 'Departments' %}">{% trans 'Departments' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/quartieri/" title="{% trans 'Campus residences' %}">{% trans 'Campus residences' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/servizio-mensa/" title="{% trans 'Canteen services' %}">{% trans 'Canteen services' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/biblioteche/" title="{% trans 'Libraries' %}">{% trans 'Libraries' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/sistema-museale/" title="{% trans 'Museum hub' %}">{% trans 'Museum hub' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/teatri-e-cinema/" title="{% trans 'Theaters and cinemas' %}">{% trans 'Theaters and cinemas' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/centro-linguistico-di-ateneo/" title="{% trans 'Language Centre' %}">{% trans 'Language Centre' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/centro-sanitario/" title="{% trans 'Health Center' %}">{% trans 'Health Center' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/centro-sportivo/" title="{% trans 'Sports Center' %}">{% trans 'Sports Center' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/centro-congressi/" title="{% trans 'Convention Center' %}">{% trans 'Convention Center' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/polo-infanzia/" title="{% trans 'Infants Center' %}">{% trans 'Infants Center' %}</a></li>
                    <li><a class="list-item" href="/campus/vivere-il-campus/servizio-foresteria/" title="{% trans 'Accomodation - Socrates Residence' %}">{% trans 'Accomodation - Socrates Residence' %}</a></li>
                    <li><a class="list-item" href="/campus/visita-il-campus/territorio/" title="{% trans 'Territory info' %}">{% trans 'Territory info' %}</a></li>
                </ul>
            </div>
        </div>
        {% endblock third_column %}

        {% block fourth_column %}
        <div class="col-lg-3 col-sm-6 pb-2">
            <h4>
                <span>
                    {% trans 'Transparent UniCal' %}
                </span>
            </h4>
            <div class="link-list-wrapper">
                <ul class="footer-list link-list clearfix">
                    <li><a class="list-item" href="/organizzazione/strutture/direzioni-aree/" title="{% trans 'Organization' %}">{% trans 'Organization' %}</a></li>
                    <li><a class="list-item" href="/organizzazione/chi-siamo/portale-trasparenza/" title="{% trans 'Transparent administration' %}">{% trans 'Transparent administration' %}</a></li>
                    <li><a class="list-item" href="https://unical.portaleamministrazionetrasparente.it/contenuto6771_segnalazione-di-illeciti-whistleblowing_769.html" target="_blank" title="{% trans 'Whistleblowing' %}">{% trans 'Whistleblowing' %}</a></li>
                    <li><a class="list-item" href="/organizzazione/chi-siamo/linee-strategiche/" title="{% trans 'Strategic plan 2023/2025' %}">{% trans 'Strategic plan 2023/2025' %}</a></li>
                    <li><a class="list-item" href="/organizzazione/chi-siamo/organi/" title="{% trans 'Governing bodies' %}">{% trans 'Governing bodies' %}</a></li>
                    <li><a class="list-item" href="https://titulus-unical.cineca.it/albo/" target="_blank" rel="noopener noreferrer" title="{% trans 'Official register of the University' %}">{% trans 'Official register of the University' %}</a></li>
                    <li><a class="list-item" href="/attidinotifica" target="_blank" title="{% trans 'Notification documents' %}">{% trans 'Notification documents' %}</a></li>
                    <li><a class="list-item" href="/organizzazione/chi-siamo/assicurazione-qualita/" title="{% trans 'Quality Assurance System' %}">{% trans 'Quality Assurance System' %}</a></li>
                    <li><a class="list-item" href="/consigliera-di-fiducia/" title="{% trans 'Trusted Advisor of the University' %}">{% trans 'Trusted Advisor of the University' %}</a></li>
                    <li><a class="list-item" href="/organizzazione/chi-siamo/organi/altri-organi-e-organismi/commissione-etica/" title="{% trans 'Code of ethics and conduct' %}">{% trans 'Code of ethics and conduct' %}</a></li>
                    <li><a class="list-item" href="/innovazione-societa/trasferimento-tecnologico/creazione-imprese-innovative/spin-off/" title="{% trans 'Spinoff / Patent Showcase' %}">{% trans 'Spinoff / Patent Showcase' %}</a></li>
                    <li><a class="list-item" href="/5x1000" title="{% trans 'Fundraising, donations, 5x1000' %}">{% trans 'Fundraising, donations, 5x1000' %}</a></li>
                </ul>
            </div>
        </div>
        {% endblock fourth_column %}

    </div>
</section>
{% endblock footer_menu_section %}

{% block footer_contacts_section %}
{% endblock footer_contacts_section %}

{% block footer_bottom %}
<div class="it-footer-main clearfix py-4 border-white border-top unical-secondary-footer">
    <div class="container">
        <section>
            {% block footer_bottom_content %}
            <div class="row">
                <div class="col-12 col-lg-9">
                    <div class="row">
                        <div class="col-lg-3 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="/pec/" title="{% trans 'Certified email' %}">{% trans 'Certified email' %}</a></li>
                                    <li><a class="list-item" href="/fatturazione-elettronica/" title="{% trans 'Electronic invoicing' %}">{% trans 'Electronic invoicing' %}</a></li>
                                    <li><a class="list-item" href="mailto:redazioneportale@unical.it" title="{% trans 'Web editor / Contacts' %}">{% trans 'Web editor / Contacts' %}</a></li>
                                    <li><a class="list-item" href="/accessibilita/" title="{% trans 'Accessibility and performance' %}">{% trans 'Accessibility and performance' %}</a></li>
                                </ul>
                            </div>
                        </div>

                        <div class="col-lg-3 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="/privacy/" title="{% trans 'Data protection / GDPR' %}">{% trans 'Data protection / GDPR' %}</a></li>
                                    <li><a class="list-item" href="/cookie/" title="{% trans 'Cookies and consent methods' %}">{% trans 'Cookies and consent methods' %}</a></li>
                                    <li><a class="list-item" href="/note-legali/" title="{% trans 'Legal notes' %}">{% trans 'Legal notes' %}</a></li>
                                    <li><a class="list-item" href="/credits/" title="{% trans 'Credits' %}">{% trans 'Credits' %}</a></li>
                                </ul>
                            </div>
                        </div>

                        <div class="col-lg-3 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="/media/medias/2021/phishing.pdf" title="{% trans 'Phishing: how to protect yourself' %}">{% trans 'Phishing: how to protect yourself' %}</a></li>
                                    <li><a class="list-item" href="/statistiche-accessi-web" title="{% trans 'Web access statistics' %}">{% trans 'Web access statistics' %}</a></li>
                                    <li><a class="list-item" href="/servizi-ict/servizi-digitali-per-il-personale/gestione-sito/" title="{% trans 'User Guide - UniCMS' %}">{% trans 'User Guide - UniCMS' %}</a></li>
                                    <li><a class="list-item" href="/editorial-board/" title="{% trans 'Intranet area' %}">{% trans 'Intranet area' %}</a></li>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-3 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="/feed-rss/" title="{% trans 'RSS feeds' %}">{% trans 'RSS feeds' %}</a></li>
                                    <li><a class="list-item" href="/sezione-alumni" title="{% trans 'Alumni' %}">{% trans 'Alumni' %}</a></li>
                                    <li><a class="list-item" href="/identita-visiva-di-ateneo/" title="{% trans 'Identity / Logo section' %}">{% trans 'Identity / Logo section' %}</a></li>
                                    <li><a class="list-item" href="/sitemap/" title="{% trans 'Sitemap' %}">{% trans 'Sitemap' %}</a></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12 col-lg-3">
                    <div class="mb-3">
                        <image src="{% unicms_template_unical_static_path 'images/logo_unical_white.svg' %}"
                               class="w-100 h-100"
                               alt="{% trans 'University of Calabria' %}"/>
                    </div>
                    <p class="mb-4">
                        Via Pietro Bucci
                        <br>
                        87036 Rende CS
                        <br>
                        <a class="text-white" href="/pec/" title="{% trans 'Certified email' %}">{% trans 'Certified email' %}</a>
                        <br>
                        C.F. 80003950781 / P.I. 00419160783
                    </p>
                </div>
            </div>
            {% endblock footer_bottom_content %}
        </section>
    </div>
</div>
{% endblock footer_bottom %}

{% block extra_scripts %}
{{ block.super }}
<script src="{% unicms_template_unical_static_path 'js/external_link_new_tab.js' %}"></script>
{% endblock extra_scripts %}
